@@ -1,12 +1,12 @@
-#  File R/predict.ergmm.R in package latentnet, part of the Statnet suite
-#  of packages for network analysis, https://statnet.org .
+#  File R/predict.ergmm.R in package latentnet, part of the
+#  Statnet suite of packages for network analysis, https://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
 #  open source, and has the attribution requirements (GPL Section 7) at
-#  https://statnet.org/attribution
+#  https://statnet.org/attribution .
 #
-#  Copyright 2003-2020 Statnet Commons
-#######################################################################
+#  Copyright 2003-2022 Statnet Commons
+################################################################################
 #' Predicted Dyad Values for an ERGMM.
 #' 
 #' Returns a matrix of expected dyad values based on an ERGMM fit.
@@ -33,7 +33,7 @@
 #' @importFrom stats predict
 #' @export
 predict.ergmm<-function(object,...,type="post"){
-  if(class(type)=="list"){
+  if(inherits(type,"list")){
     type<-type
   }else if(type=="start"){
     type<-object[["start"]]
